#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using NUnit.Framework;
using Utilities.Testing;
using Utilities.Text;
using System.Text.RegularExpressions;
using System;

namespace Utilities.Test.Text
{
  public class RegexUtilsFixture : TestFixtureBase
  {
    [Test]
    public void ToRegexPattern()
    {
      string regexPattern;
      bool regexMatchResult;

      regexPattern = RegexUtils.ToRegexPattern("*.*");
      Assert.AreEqual(@".*?\..*?", regexPattern);

      regexMatchResult = Regex.IsMatch("Pie", regexPattern);
      Assert.AreEqual(false, regexMatchResult);

      regexMatchResult = Regex.IsMatch("Pie.txt", regexPattern);
      Assert.AreEqual(true, regexMatchResult);

      regexPattern = RegexUtils.ToRegexPattern("?oom");
      Assert.AreEqual(@".oom", regexPattern);

      regexMatchResult = Regex.IsMatch("Pie", regexPattern);
      Assert.AreEqual(false, regexMatchResult);

      regexMatchResult = Regex.IsMatch("Boom", regexPattern);
      Assert.AreEqual(true, regexMatchResult);

      regexPattern = RegexUtils.ToRegexPattern(string.Empty);
      Assert.AreEqual(string.Empty, regexPattern);
    }

    [Test]
    [ExpectedException(typeof(ArgumentNullException), ExpectedMessage = @"Value cannot be null.
Parameter name: wildcardSearch")]
    public void ToRegexPatternNull()
    {
      RegexUtils.ToRegexPattern(null);
    }
  }
}